@@ -257,8 +257,8 @@ def get_pin_num_and_spacer(pin):
     pin_num = str(pin.num)
     pin_spacer = 0
     # spacer pins have pin numbers starting with a special prefix char.
-    if pin_num.startswith(PIN_SPACER_PREFIX):
-        pin_spacer = 1
+    while pin_num.startswith(PIN_SPACER_PREFIX):
+        pin_spacer += 1
         pin_num = pin_num[1:]  # Remove the spacer prefix.
     return pin_num, pin_spacer
 
@@ -446,14 +446,10 @@ def draw_pins(unit_num, unit_pins, bbox, transform, side, push, fuzzy_match):
 
         # Create all the pins with a particular name. If there are more than one,
         # pin numbers are hidden, and everything after the first are hidden.
-        # num_size = PIN_NUM_SIZE if len(pins) == 1 else 0
+        num_size = PIN_NUM_SIZE if pin_type != "N" else 0
         for index, pin in enumerate(pins):
 
-            pin_num = str(pin.num)
-
-            # Remove any spacer prefix on the pin numbers.
-            if pin_num.startswith(PIN_SPACER_PREFIX):
-                pin_num = pin_num[1:]
+            pin_num, _ = get_pin_num_and_spacer(pin)
 
             # Create a pin using the pin data.
             pin_defn += PIN.format(
@@ -463,8 +459,7 @@ def draw_pins(unit_num, unit_pins, bbox, transform, side, push, fuzzy_match):
                 y=int(draw_y),
                 length=PIN_LENGTH,
                 orientation=pin_side,
-                num_sz=PIN_NUM_SIZE,
-                # num_sz=num_size,
+                num_sz=num_size,
                 name_sz=PIN_NAME_SIZE,
                 unit_num=unit_num,
                 pin_type=pin_type,
@@ -577,10 +572,8 @@ def draw_symbol(
                 break
 
     # Create the field that stores the part reference.
-    if not part_ref_prefix:
-        part_ref_prefix = "U"
     part_defn += REF_FIELD.format(
-        ref_prefix=part_ref_prefix,
+        ref_prefix=part_ref_prefix or "U",
         x=XO + horiz_offset,
         y=YO + REF_Y_OFFSET + vert_offset,
         text_justification=text_justification,
@@ -588,10 +581,8 @@ def draw_symbol(
     )
 
     # Create the field that stores the part number.
-    if not part_num:
-        part_num = ""
     part_defn += PARTNUM_FIELD.format(
-        num=part_num,
+        num=part_num or "",
         x=XO + horiz_offset,
         y=YO + PART_NUM_Y_OFFSET + vert_offset,
         text_justification=text_justification,
@@ -599,10 +590,8 @@ def draw_symbol(
     )
 
     # Create the field that stores the part footprint.
-    if not part_footprint:
-        part_footprint = ""
     part_defn += FOOTPRINT_FIELD.format(
-        footprint=part_footprint,
+        footprint=part_footprint or "",
         x=XO + horiz_offset,
         y=YO + PART_FOOTPRINT_Y_OFFSET + vert_offset,
         text_justification=text_justification,
@@ -610,10 +599,8 @@ def draw_symbol(
     )
 
     # Create the field that stores the datasheet link.
-    if not part_datasheet:
-        part_datasheet = ""
     part_defn += DATASHEET_FIELD.format(
-        datasheet=part_datasheet,
+        datasheet=part_datasheet or "",
         x=XO + horiz_offset,
         y=YO + PART_DATASHEET_Y_OFFSET + vert_offset,
         text_justification=text_justification,
